@@ -1,10 +1,15 @@
+# -*- encoding: utf-8 -*-
+# Template language benchmarks
+#
+# Objective: Test general templating features using a small template
+
 from cgi import escape
 import os
 from StringIO import StringIO
 import sys
 import timeit
 
-__all__ = ['clearsilver', 'django', 'kid', 'genshi', 'simpletal']
+__all__ = ['clearsilver', 'myghty', 'django', 'kid', 'genshi', 'cheetah']
 
 def genshi(dirname, verbose=False):
     from genshi.template import TemplateLoader
@@ -19,9 +24,30 @@ def genshi(dirname, verbose=False):
         print render()
     return render
 
+def myghty(dirname, verbose=False):
+    try:
+        from myghty import interp
+    except ImportError:
+        print>>sys.stderr, 'Mighty not installed, skipping'
+        return lambda: None
+    interpreter = interp.Interpreter(component_root=dirname)
+    def render():
+        data = dict(title='Just a test', user='joe',
+                    items=['Number %d' % num for num in range(1, 15)])
+        buffer = StringIO()
+        interpreter.execute("template.myt", request_args=data, out_buffer=buffer)
+        return buffer.getvalue()
+    if verbose:
+        print render()
+    return render
+
 def cheetah(dirname, verbose=False):
     # FIXME: infinite recursion somewhere... WTF?
-    from Cheetah.Template import Template
+    try:
+        from Cheetah.Template import Template
+    except ImportError:
+        print>>sys.stderr, 'Cheetah not installed, skipping'
+        return lambda: None
     class MyTemplate(Template):
         def serverSidePath(self, path): return os.path.join(dirname, path)
     filename = os.path.join(dirname, 'template.tmpl')
@@ -38,7 +64,11 @@ def cheetah(dirname, verbose=False):
     return render
 
 def clearsilver(dirname, verbose=False):
-    import neo_cgi
+    try:
+        import neo_cgi
+    except ImportError:
+        print>>sys.stderr, 'ClearSilver not installed, skipping'
+        return lambda: None
     neo_cgi.update()
     import neo_util
     import neo_cs
@@ -58,8 +88,12 @@ def clearsilver(dirname, verbose=False):
     return render
 
 def django(dirname, verbose=False):
-    from django.conf import settings
-    settings.configure(TEMPLATE_DIRS=[os.path.join(dirname, 'templates')])
+    try:
+        from django.conf import settings
+        settings.configure(TEMPLATE_DIRS=[os.path.join(dirname, 'templates')])
+    except ImportError:
+        print>>sys.stderr, 'Django not installed, skipping'
+        return lambda: None
     from django import template, templatetags
     from django.template import loader
     templatetags.__path__.append(os.path.join(dirname, 'templatetags'))
@@ -75,32 +109,29 @@ def django(dirname, verbose=False):
     return render
 
 def kid(dirname, verbose=False):
-    import kid
+    try:
+        import kid
+    except ImportError:
+        print>>sys.stderr, "SimpleTAL not installed, skipping"
+        return lambda: None
     kid.path = kid.TemplatePath([dirname])
-    template = kid.Template(file='template.kid')
+    template = kid.load_template('template.kid').Template
     def render():
-        template = kid.Template(file='template.kid',
-                                title='Just a test', user='joe',
-                                items=['Number %d' % num for num in range(1, 15)])
-        return template.serialize(output='xhtml')
-
-    if verbose:
-        print render()
-    return render
-
-def nevow(dirname, verbose=False):
-    # FIXME: can't figure out the API
-    from nevow.loaders import xmlfile
-    template = xmlfile('template.xml', templateDir=dirname).load()
-    def render():
-        print template
+        return template(
+            title='Just a test', user='joe',
+            items=['Number %d' % num for num in range(1, 15)]
+        ).serialize(output='xhtml')
 
     if verbose:
         print render()
     return render
 
 def simpletal(dirname, verbose=False):
-    from simpletal import simpleTAL, simpleTALES
+    try:
+        from simpletal import simpleTAL, simpleTALES
+    except ImportError:
+        print>>sys.stderr, "SimpleTAL not installed, skipping"
+        return lambda: None
     fileobj = open(os.path.join(dirname, 'base.html'))
     base = simpleTAL.compileHTMLTemplate(fileobj)
     fileobj.close()
